prediction_scale

Function prediction_scale 

pub fn prediction_scale(level: f64, count: usize) -> Result<f64, AnalysisError>
The scale k of the ellipse a new flight lands in with probability level, from count normal landings whose mean and covariance were estimated: k² = ((n² − 1)/n) ((1 − level)^(−2/(n − 2)) − 1) (the module’s docs).

Errors