#[non_exhaustive]pub enum Stop {
Target,
Evaluations,
TolX,
TolFun,
Condition,
Bounds,
}Expand description
Why a run stopped.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Target
A value at or below the target was found.
Evaluations
The evaluations allowed were used up.
TolX
The distribution’s spread, and its evolution path, fell below the tolerance in every variable: the run has converged in the variables.
TolFun
The values stopped changing by more than the tolerance: converged in the output.
Condition
The covariance’s condition number passed MAX_CONDITION, or the step size or a
candidate overflowed: the run has diverged, or its distribution has degenerated.
Bounds
A candidate of a generation didn’t fall inside the bounds in MAX_DRAWS tries.