pub struct Sobol { /* private fields */ }Expand description
A Sobol’ analysis: the factors and the number of rows N of each of the samples A and B.
It serializes as its fields, and reads back through Sobol::new’s checks.
Implementations
Sourceimpl Sobol
impl Sobol
Sourcepub fn new(factors: Vec<Factor>, rows: usize) -> Result<Self, AnalysisError>
pub fn new(factors: Vec<Factor>, rows: usize) -> Result<Self, AnalysisError>
An analysis of factors with rows rows in each of A and B.
Errors
AnalysisError::TooFewwith no factors, or fewer than 2 rows (a standard error needs two).AnalysisError::DuplicateFactorfor two factors with one name.AnalysisError::Countfor a design of more thanMAX_DESIGN_POINTSpoints orMAX_DESIGN_VALUEScoordinates.
Sourcepub fn design(&self, seed: u64) -> SobolDesign
pub fn design(&self, seed: u64) -> SobolDesign
The design seeded with seed. Row j draws from its own stream,
SeededRng::for_stream(seed, &[j]), k uniform deviates for A’s row and then k
for B’s, so it is the same however many rows are drawn.
Sourcepub fn indices(
&self,
seed: u64,
model: impl FnMut(&[f64]) -> f64,
) -> Result<SobolIndices, AnalysisError>
pub fn indices( &self, seed: u64, model: impl FnMut(&[f64]) -> f64, ) -> Result<SobolIndices, AnalysisError>
Draws the design seeded with seed, runs model at each of its points in order, and
analyses the outputs (SobolDesign::analyze).
Errors