pub fn dominates(a: &[f64], b: &[f64]) -> bool
Whether a’s goals dominate b’s: no worse in any, better in at least one. The two should be the same length; only as many goals as the shorter has are compared.
a
b